document.addEventListener('DOMContentLoaded', () => {
  const tocLinks = document.querySelectorAll('#toc a');
  const sections = document.querySelectorAll('section');
  const OFFSET = 200;          // Offset for triggering section visibility
  const SCROLL_OFFSET = 150;   // Scroll offset for the top position of the section

  function highlightTOC() {
    let index = sections.length;

    // Determine which section is currently visible considering OFFSET
    while (--index && window.scrollY + OFFSET < sections[index]?.offsetTop) {}

    tocLinks.forEach((link) => link.classList.remove('active'));

    // Highlight the TOC link corresponding to the section
    // Consider SCROLL_OFFSET for the top position of the section
    if (index >= 0 && sections[index] && window.scrollY + SCROLL_OFFSET >= sections[index].offsetTop) {
      tocLinks[index].classList.add('active');
    }
  }

  function scrollToSection(event) {
    event.preventDefault(); // Prevent the default anchor behavior

    const targetId = this.getAttribute('href').substring(1); // Get the target section id from href
    const targetSection = document.getElementById(targetId);

    if (targetSection) {
      const offsetTop = targetSection.offsetTop;
      window.scrollTo({
        top: offsetTop - SCROLL_OFFSET,
        behavior: 'smooth'
      });
    }
  }

  // Attach click event listeners to TOC links
  tocLinks.forEach((link) => {
    link.addEventListener('click', scrollToSection);
  });

  // Debounce function to limit the rate at which a function can fire.
  function debounce(func, wait = 10, immediate = true) {
    let timeout;
    return function () {
      const context = this, args = arguments;
      const later = function () {
        timeout = null;
        if (!immediate) func.apply(context, args);
      };
      const callNow = immediate && !timeout;
      clearTimeout(timeout);
      timeout = setTimeout(later, wait);
      if (callNow) func.apply(context, args);
    };
  }

  highlightTOC(); // Initial call to set the correct state on load
  window.addEventListener('scroll', debounce(highlightTOC)); // Attach the scroll event listener
});


// TOC following camera
window.addEventListener('scroll', function () {
  const fixedElement = document.getElementById('toc');
  const container = document.getElementById('fixedContainer');

  if (fixedElement && container) {
    const containerRect = container.getBoundingClientRect();
    const elementHeight = fixedElement.offsetHeight;
    const containerHeight = container.offsetHeight;

    // Check if the container is in the viewport
    if (containerRect.top <= 150 && containerRect.bottom >= elementHeight + 150) {
      // Fix the TOC 150px from the top of the viewport
      fixedElement.style.top = '150px';
      fixedElement.style.position = 'fixed';
    } else if (containerRect.bottom < elementHeight + 150) {
      // Fix the TOC at the bottom of the container
      fixedElement.style.position = 'absolute';
      fixedElement.style.top = (containerHeight - elementHeight) + 'px';
    } else {
      // Reset TOC to its original position
      fixedElement.style.position = 'absolute';
      fixedElement.style.top = '0px';
    }
  }
});


//NAVIGATION BAR - DROPDOWN MENUS
document.addEventListener('DOMContentLoaded', function() {
  const dropdownToggles = document.querySelectorAll('.dropdown_toggle');
  const dropdownMenus = document.querySelectorAll('.dropdown_menu');
  const toggleBtn = document.querySelector('.toggle_btn');
  const navbarLinks = document.querySelector('.links');

  let currentlyOpenDropdown = null;

  function closeAllDropdowns() {
      dropdownMenus.forEach(menu => menu.classList.remove('open'));
      currentlyOpenDropdown = null;
  }

  // Handle link dropdowns
  dropdownToggles.forEach(toggle => {
      toggle.addEventListener('click', function(event) {
          // Prevent default link behavior
          event.preventDefault();
          // Close currently open dropdown if it's not the clicked one
          if (currentlyOpenDropdown && currentlyOpenDropdown !== this.nextElementSibling) {
              closeAllDropdowns();
          }
          // Toggle the clicked dropdown
          const dropdownMenu = this.nextElementSibling;
          if (dropdownMenu.classList.contains('open')) {
              dropdownMenu.classList.remove('open');
              currentlyOpenDropdown = null;
          } else {
              dropdownMenu.classList.add('open');
              currentlyOpenDropdown = dropdownMenu;
          }
          event.stopPropagation();
      });
  });

  // Handle toggle button for mobile menu
  toggleBtn.addEventListener('click', function() {
      navbarLinks.classList.toggle('open');
      // Close all dropdowns when toggling mobile menu
      closeAllDropdowns();
  });

  // Close dropdowns and mobile menu when clicking outside
  document.addEventListener('click', function(event) {
      if (!navbarLinks.contains(event.target) && !toggleBtn.contains(event.target)) {
          closeAllDropdowns();
          navbarLinks.classList.remove('open');
      }
  });

  // Prevent dropdown closing when clicking inside the dropdown
  dropdownMenus.forEach(menu => {
      menu.addEventListener('click', function(event) {
          event.stopPropagation();
      });
  });

  // Close the dropdown menu if the screen gets larger than 650px
  window.addEventListener('resize', function() {
      if (window.innerWidth > 650) {
          closeAllDropdowns();
          navbarLinks.classList.remove('open');
      }
  });
});

document.addEventListener('DOMContentLoaded', function () {
  // Get the image container and the overlay
  const imageContainer = document.querySelector('.image-container');
  const overlay = document.querySelector('.overlay');


  // Toggle overlay visibility on click of the image container
  imageContainer.addEventListener('click', function (event) {
    console.log('Image container clicked');
    imageContainer.classList.toggle('active');
    event.stopPropagation(); // Prevent the click event from bubbling to the document
  });

  // Hide the overlay when clicking outside the image container
  document.addEventListener('click', function () {
    console.log('Document clicked');
    if (imageContainer.classList.contains('active')) {
      imageContainer.classList.remove('active');
    }
  });

  // Prevent overlay from closing if clicking on the overlay itself
  overlay.addEventListener('click', function (event) {
    console.log('Overlay clicked');
    event.stopPropagation(); // Prevent the click event from closing the overlay
  });
});
